/*CODE USED TO GENERATE TABLES 1 AND 2*/

/*read in data imputed in R using Amelia*/
/*alter the pathname below as needed to match the location of the file on your computer*/
use "/Users/andrewamiles/Documents/Duke/Predictions with MI data/gss_imputed.dta", clear
mi import flong, m(imp) id(id) imp(prestige-realrinc female)

/*check import*/
mi describe
mi varying
drop imp
/*reshape to normal MI format*/
mi convert wide, clear 

/*estimate a baseline comparison model*/
reg prestg80 i.degree i.padeg papres80 i.year [pweight=wtssall]
su papres80, d
margins, at(papres80=(22 24 30 35 40 51 64 69 75) degree=2 padeg=2 ///
	year=1)

/*now estimate the model with MI data*/
/*those originally missing on outcome*/
gen origmiss=missing(prestg80)

mi estimate, dots post: ///
	reg prestg80 i.degree i.padeg papres80 i.year ///
	if origmiss==0 [pweight=wtssall] 
est store m1

/*predict using the predict then combine approach*/
/*I originally used the technique outlined here:
http://www.ats.ucla.edu/stat/stata/faq/ologit_mi_marginsplot.htm 
but have replaced it with the much simpler mimrgns command below
- the speeds of the two commands are comparable*/
/*what is prestige for those at various percentiles of father's 
occupational prestige?, for respondent and father with high school educ?*/
su papres80, d 
est restore m1
timer on 1
mimrgns, at(papres80=(22 24 30 35 40 51 64 69 75) degree=2 padeg=2 ///
	year=1)
est store pc1
timer off 1
timer list 1  

/*predict directly from the combined model - combine then predict method*/
est restore m1
timer on 2
/*create a vector of predictions*/
matrix s1=(0,1,0,0,0,0,1,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1)
matrix preds1 = s1*e(b)'
matrix s2=(0,1,0,0,0,0,1,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1)
matrix preds2 = s2*e(b)'
matrix s3=(0,1,0,0,0,0,1,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1)
matrix preds3 = s3*e(b)'
matrix s4=(0,1,0,0,0,0,1,0,0,0,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1)
matrix preds4 = s4*e(b)'
matrix s5=(0,1,0,0,0,0,1,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1)
matrix preds5 = s5*e(b)'
matrix s6=(0,1,0,0,0,0,1,0,0,0,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1)
matrix preds6 = s6*e(b)'
matrix s7=(0,1,0,0,0,0,1,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1)
matrix preds7 = s7*e(b)'
matrix s8=(0,1,0,0,0,0,1,0,0,0,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1)
matrix preds8 = s8*e(b)'
matrix s9=(0,1,0,0,0,0,1,0,0,0,75,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1)
matrix preds9 = s9*e(b)'

/*calculate the SE of the prediction*/
matrix vcov1=s1*e(V)*s1'
matrix vcov2=s2*e(V)*s2'
matrix vcov3=s3*e(V)*s3'
matrix vcov4=s4*e(V)*s4'
matrix vcov5=s5*e(V)*s5'
matrix vcov6=s6*e(V)*s6'
matrix vcov7=s7*e(V)*s7'
matrix vcov8=s8*e(V)*s8'
matrix vcov9=s9*e(V)*s9'
scalar define se1 = sqrt(vcov1[1,1])
scalar define se2 = sqrt(vcov2[1,1])
scalar define se3 = sqrt(vcov3[1,1])
scalar define se4 = sqrt(vcov4[1,1])
scalar define se5 = sqrt(vcov5[1,1])
scalar define se6 = sqrt(vcov6[1,1])
scalar define se7 = sqrt(vcov7[1,1])
scalar define se8 = sqrt(vcov8[1,1])
scalar define se9 = sqrt(vcov9[1,1])

/*compile results*/
matrix predmat= (preds1, se1 \ preds2, se2 \ preds3, se3 \ preds4, se4 \ ///
	preds5, se5 \ preds6, se6 \ preds7, se7 \ preds8, se8 \ preds9, se9)
matrix colnames predmat = prediction SE
matrix list predmat
	
timer off 2
timer list 2

/*now a more complicated question - has the coefficient for 
father's prestige changed over time?*/
reg prestg80 i.degree i.padeg c.papres80##i.year ///
	if origmiss==0 [pweight=wtssall]
margins year, dydx(papres80) at(degree=2 padeg=2)

mi estimate, dots post: ///
	reg prestg80 i.degree i.padeg c.papres80##i.year ///
	if origmiss==0 [pweight=wtssall]
est store m2

timer on 3
mimrgns year, dydx(papres80) at(degree=2 padeg=2)
est store pc2
timer off 3
timer list 3  

/*combine then predict method*/
/*clear out results from last time*/
matrix drop s1 s2 s3 s4 s5 s6 s7 s8 s9 vcov1 vcov2 vcov3 vcov4 vcov5 ///
vcov6 vcov7 vcov8 vcov9 predmat
scalar drop se1 se2 se3 se4 se5 se6 se7 se8 se9

est restore m2
timer on 4
/*calculate the predictions*/
*1988
matrix s0=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
matrix preds0 = s0*e(b)'
*1989
matrix s=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0)
matrix preds1 = s*e(b)'
*1990
matrix s2=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0)
matrix preds2 = s2*e(b)'
*1991
matrix s3=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0)
matrix preds3 = s3*e(b)'
*1993
matrix s4=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0)
matrix preds4 = s4*e(b)'
*1994
matrix s5=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0)
matrix preds5 = s5*e(b)'
*1996
matrix s6=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0)
matrix preds6 = s6*e(b)'
*1998
matrix s7=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0)
matrix preds7 = s7*e(b)'
*2000
matrix s8=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0)
matrix preds8 = s8*e(b)'
*2002
matrix s9=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0)
matrix preds9 = s9*e(b)'
*2004
matrix s10=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0)
matrix preds10 = s10*e(b)'
*2006
matrix s11=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0)
matrix preds11 = s11*e(b)'
*2008
matrix s12=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0)
matrix preds12 = s12*e(b)'
*2010
matrix s13=(0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0)
matrix preds13 = s13*e(b)'


/*calculate the SE of the prediction*/
*1988
matrix vcov=s0*e(V)*s0'
scalar define se0 = sqrt(vcov[1,1])
matrix drop vcov
*1989
matrix vcov=s*e(V)*s'
scalar define se1 = sqrt(vcov[1,1])
matrix drop vcov
*1990
matrix vcov=s2*e(V)*s2'
scalar define se2 = sqrt(vcov[1,1])
matrix drop vcov
*1991
matrix vcov=s3*e(V)*s3'
scalar define se3 = sqrt(vcov[1,1])
matrix drop vcov
*1993
matrix vcov=s4*e(V)*s4'
scalar define se4 = sqrt(vcov[1,1])
matrix drop vcov
*1994
matrix vcov=s5*e(V)*s5'
scalar define se5 = sqrt(vcov[1,1])
matrix drop vcov
*1996
matrix vcov=s6*e(V)*s6'
scalar define se6 = sqrt(vcov[1,1])
matrix drop vcov
*1998
matrix vcov=s7*e(V)*s7'
scalar define se7 = sqrt(vcov[1,1])
matrix drop vcov
*2000
matrix vcov=s8*e(V)*s8'
scalar define se8 = sqrt(vcov[1,1])
matrix drop vcov
*2002
matrix vcov=s9*e(V)*s9'
scalar define se9 = sqrt(vcov[1,1])
matrix drop vcov
*2004
matrix vcov=s10*e(V)*s10'
scalar define se10 = sqrt(vcov[1,1])
matrix drop vcov
*2006
matrix vcov=s11*e(V)*s11'
scalar define se11 = sqrt(vcov[1,1])
matrix drop vcov
*2008
matrix vcov=s12*e(V)*s12'
scalar define se12 = sqrt(vcov[1,1])
matrix drop vcov
*2010
matrix vcov=s13*e(V)*s13'
scalar define se13 = sqrt(vcov[1,1])
matrix drop vcov

matrix predmat2= (preds0, se0 \ preds1, se1 \ preds2, se2 \ preds3, se3 \ ///
	preds4, se4 \ preds5, se5 \ preds6, se6 \ preds7, se7 \ preds8, se8 \ ///
	preds9, se9 \ preds10, se10 \ preds11, se11 \ preds12, se12 \ ///
	preds13, se13)
matrix colnames predmat2 = prediction SE
matrix list predmat2

timer off 4
timer list 4 



